********************************************************************************
********************************************************************************
*** Creation indicateurs sorties de l'indemn avec une indicatrice vers l'emploi
********************************************************************************
********************************************************************************


clear all
set more off

*To be personalized
*gl testing_AR /Users/pv/Dropbox/Testing_AR/
gl testing_AR "/Users/helene/Dropbox/#Work/#Projets/Testing AR/Testing_AR/"

gl testing_AR_in "${testing_AR}Prog/Prog for JHR/Data/Raw data/"
gl testing_AR_out "${testing_AR}Prog/Prog for JHR/Data/Intermediate tables/"	

********************************************************************************
*** 1 DPAE 
********************************************************************************

use "${testing_AR_in}sit_ire_kcrna", clear

drop ident kcass krin

*Change date format
tostring mois_ire, replace
gen mois=substr(mois_ire,5,6 )
destring mois, replace
gen annee=substr(mois_ire,1,4 )
destring annee, replace
drop mois_ire

*We add starting date of U spell
merge m:m kcrna using "${testing_AR_in}pop_pour_tirage_finale", keepusing(kcrna date_odd)
keep if _merge == 3
drop _merge

order kcrna date_odd annee mois retour
sort kcrna date_odd annee mois

*We are only interested in the hiring after july 2016
keep if (annee >= 2017 | (mois>=month(date_odd) & annee==2016)) 

/*
D1 = Permanent contract
D2 = Fixed term contract > 6 months
D3 = Fixed term contract 3 to 6 months
D4 = Fixed term contract 1 to 3 months
C = category C
AP = AFPR/POE 
E = category E
RD = the jobseeker declared he/she found a job
*/

replace retour = "CDI" if retour == "D1"
replace retour = "CDD_sup6m" if retour == "D2"
replace retour = "CDD_3a6m" if retour == "D3"
replace retour = "CDD_1a3m" if retour == "D4"
replace retour = "cat_E" if retour == "E"
replace retour = "cat_C" if retour == "C"

drop if retour == "AP"

rename retour indic_DPAE

duplicates drop kcrna annee mois, force

save "${testing_AR_out}indicateurs_DPAE", replace

********************************************************************************
*** 2 PAF 
********************************************************************************

use "${testing_AR_in}hnov19_paf", clear

gen duree_contrat_PAF = kdfpe - kddpe + 1
replace	duree_contrat_PAF = . if kdfpe == mdy(12,30, 9998) | kddpe == mdy(12,30, 9998)

gen indic_PAF = kcmcaf
rename kddpe date_debut_contrat

keep individu date_debut_contrat duree_ indic_

*adding id of job seekers
merge m:1 individu using "${testing_AR_in}hnov19_ind", keepusing(kcrna)
keep if _merge==3
drop _merge

*We add starting date of U spell
merge m:m kcrna using "${testing_AR_in}pop_pour_tirage_finale", keepusing(date_odd)
keep if _merge==3
drop _merge

* We keep the contracts that start after date_odd 
keep if date_debut_contrat >= date_odd

sort kcrna date_debut_contrat 
drop individu 
order kcrna date_odd indic_ date_debut_contrat duree_ 

drop if indic_=="XX"

replace indic_ = "CDD" if indic_ == "40" | indic_ == "44" | indic_ == "45" | indic_ == "84"
replace indic_ = "Interim" if indic_ == "41"
replace indic_ = "CDI" if indic_ == "11" | indic_ == "12" | indic_ == "13" | indic_ == "14" | indic_ == "15" | indic_ == "16" | indic_ == "18" | indic_ == "19" | indic_ == "20" | indic_ == "21" | indic_ == "22" | indic_ == "25" | indic_ == "26" | indic_ == "27" | indic_ == "29" | indic_ == "42" | indic_ == "43" | indic_ == "60" | indic_ == "62"  | indic_ == "63"  | indic_ == "64"  | indic_ == "65"  | indic_ == "66"  | indic_ == "67"  | indic_ == "68"  | indic_ == "69"   | indic_ == "70"   | indic_ == "71"   | indic_ == "77"   | indic_ == "78"  | indic_ == "79"  | indic_ == "88"   
replace indic_ = "Autre" if indic_ != "CDD" & indic_ != "Interim" & indic_ != "CDI"

* We drop dublicates
bysort kcrna : drop if _n>1

gen annee = year(date_debut_contrat)
gen mois = month(date_debut_contrat)

save "${testing_AR_out}indicateurs_paf", replace

********************************************************************************
*** 3 Merge the two database DPAE et PAF 
********************************************************************************
use "${testing_AR_out}indicateurs_paf", clear

* Merge on annee mois (kcrna)
* Note : more than one ligne if the month is different from one source to the other 
merge m:m kcrna annee mois using "${testing_AR_out}indicateurs_DPAE"
sort kcrna 

gen source = "DPAE & PAF"
replace source = "DPAE" if _merge == 2
replace source = "PAF" if _merge == 1

drop _merge

rename annee annee_deb_contrat
rename mois mois_deb_contrat
rename date_debut_contrat date_deb_contrat_PAF

rename indic_PAF info_contrat_PAF
rename indic_DPAE info_contrat_DPAE

order kcrna date_odd annee mois date_deb_contrat duree info_contrat_PAF info_contrat_DPAE source
sort kcrna annee mois date_deb

rename mois_deb_contrat mois
rename annee_deb_contrat annee

save "${testing_AR_out}indicateurs_emploi", replace
