
gl confidence_level 95
gl period_by monthly 
gl borne_inf 0
gl borne_sup 36
gl controls femme ///
		   jeune senior ///
		   higher_edu lower_2nd_edu ///
		   contrat_moins_1mois contrat_moins_3mois contrat_moins_12mois ///
		   kpjdxp ///
		   kqcsjp ///
		   tx_chge ///
		   nombre_de ///
		   nombre_de_rct ///
		   proportion_de_ar ///
		   proportion_de_ld ///
		   proportion_de_sortants ///
		   i.moisregion ///
		   i.moisodd

*** Prog  

foreach s of global liste_sample { // <-- sample
	
	global sample `s' 
	use "${testing_AR_data}exploitation_panel_mai20.dta", clear // base utilisée
	
	
gen unemp_compensated = 1 - sortietotale
	gen full_unemp_uncompensated = unemp*sortietotale
	gen full_unemp_compensated = (1 - sortietotale)*(iar==0)

	keep if `s' == 1 // sample filter 

	foreach var of global controls_bis { // drop les obs pour lesquelles on a des missings dans les controls 
		drop if `var' == . 
	}
		
	if("${period_by}" == "monthly"){
		gen period = numero_mois
	}
	else{
		if("${period_by}" == "quarterly"){
			gen period = quarter
		}
		else{
			gen period == year
		}
	}
	keep if period >= ${borne_inf} & period <= ${borne_sup} 
	save "base1", replace // on save la base temporairement 

	foreach e of global liste_effet {  // <-- effet
		
		use "base1", clear 
		global effet `e'
		
		
		if("`e'" == "TvsC"){
			*gen _webal = _webal_spl_control
		}
		else{
			if("`e'" == "TvsAll"){
				*gen _webal = _webal_spl_tscontrol

			}
			else{
				if("`e'" == "CvsSC"){
					drop if treated == 1
					replace treated = 1 if controle == 1
					*gen _webal = _webal_spl_superversuscont
				}
			}
		}
		save "base2", replace
		global base "base2"
		
		
		foreach m of global liste_methode {  // <-- methode

			global method `m'

			foreach o of global liste_outcome { // <-- outcome 
			
				global outcome `o'

				foreach n of global liste_niveau_agreg { // <-- niveau agreg
					
					global niveau `n'
					
					
					* regressions
					do "${testing_AR_routines}compute_dynamic_trt_effect_by_${niveau}.do"
					
					
					* graphs 
					use "table_${sample}_${effet}_${method}_${period_by}.dta", clear

					if("`n'" == "treated"){
						twoway (line ci_lower period, lcolor(gray)) /// 
							   (line ci_upper period, lcolor(gray)) ///
							   (scatter coef period, msize(0.8) mcolor(black)), ///
									graphregion(color(white)) ///
									xline(0 1 2, lpattern(shortdash) lcolor(black)) || ///
									scatteri 0 ${borne_sup}, msymbol(i) xaxis(2) ///
									xtitle("Month before/after the treatment (first sending)", axis(1)) ///
									xtitle("", axis(2)) ///
									yline(0, lcolor(black)) ///
									legend(order(3 "OLS estimate (${effet})" 1 "${confidence_level}% CI") cols(2)) ///
									xlabel(0(2)${borne_sup}) ///
									xscale(range(${borne_inf} ${borne_sup}) axis(2)) ///
									xlab(0 "1st sending" 1 "2nd sending" 2 "3rd sending", axis(2) angle(45) labsize(2.25))
	
					}
					
				}

			}

		}
		
		erase "base2.dta"

	}
	
	erase "base1.dta"
			
}

erase "table_${sample}_${effet}_${method}_${period_by}.dta"


